<div>
  <h1 align='center'>
    umapy
  </h1>
</div>
<div>
  <p align='center'>
    A simple API wrapper of Unofficial MCOC API(UMA).
  </p>
</div>

## Install

```bash
pip install git+https://github.com/Rexians/umapy.git
```

## Basic Usage

Get Champ Info-

```py
from umapy import Client

client = Client()
abom = x.get_champ_info('ABOMINATION',6, 3)
print(abom.name)
```

- Docs soon!!

## Contribution

Feel free to contribute by either opening an issue or a pull request.
